@@ -122,17 +122,18 @@ class Drummer:
             for i in range(self.beats - 1):
                 self.note(patch)
 
-    def pattern(self, patterns=None, duration=1/4):
+    def pattern(self, patterns=None, duration=1/4, volume=None):
         if not patterns:
             return
-        for inst in self.kit.keys():
+        kit = list(self.instrument_map().keys()) + list(self.kit.keys())
+        for inst in kit:
             if inst in patterns:
                 for pattern_str in patterns[inst]:
                     for bit in pattern_str:
                         if bit == '0':
                             self.rest(inst, duration=duration)
                         else:
-                            self.note(inst, duration=duration)
+                            self.note(inst, duration=duration, volume=volume)
 
     def roll(self, name, duration=1, subdivisions=4, crescendo=[]):
         if not crescendo:
@@ -145,6 +146,13 @@ class Drummer:
             self.note(name, duration=duration/subdivisions, volume=int(volume))
             volume += factor
 
+    def write(self, filename='drums.mid', format='midi'):
+        self.score.write(format, fp=filename)
+
+    def show(self, format=None):
+        # n.b. format=None shows whatever the music21 default is set to
+        self.score.show(format)
+
     def instrument_map(self, key=None):
         kit = {
             'kick1': { 'num': 35, 'name': 'Acoustic Bass Drum', 'obj': instrument.BassDrum() },
